@@ -4,6 +4,7 @@ import threading
 import uuid
 from concurrent.futures import Future
 from contextlib import contextmanager
+from datetime import datetime, timedelta
 from typing import Optional, Union, Generator, List, Any, Dict, Tuple, Iterator
 
 from hedwig.conf import settings
@@ -12,7 +13,7 @@ from hedwig.models import Message
 from hedwig.utils import log
 
 
-class HedwigPublisherBaseBackend:
+class HedwigPublisherBaseBackend(abc.ABC):
     @classmethod
     def topic(cls, message: Message) -> Union[str, Tuple[str, str]]:
         """
@@ -86,9 +87,19 @@ class HedwigPublisherBaseBackend:
         return result
 
 
-class HedwigConsumerBaseBackend:
+class HedwigConsumerBaseBackend(abc.ABC):
     def __init__(self) -> None:
         self._error_count = 0
+        self._heartbeat_called_at = datetime(1970, 1, 1)
+        self._last_message_received_at = datetime(1970, 1, 1)
+        self._heartbeat_interval_timedelta = timedelta(seconds=settings.HEDWIG_HEARTBEAT_INTERVAL_S)
+        inactivity_reset_s = settings.HEDWIG_HEARTBEAT_INACTIVITY_RESET_S
+        self._heartbeat_inactivity_reset_timedelta = None
+        if inactivity_reset_s:
+            self._heartbeat_inactivity_reset_timedelta = timedelta(seconds=inactivity_reset_s)
+
+    def heartbeat_hook_kwargs(self) -> dict:
+        return {"error_count": self.error_count}
 
     @staticmethod
     def pre_process_hook_kwargs(queue_message) -> dict:
@@ -98,12 +109,18 @@ class HedwigConsumerBaseBackend:
     def post_process_hook_kwargs(queue_message) -> dict:
         return {}
 
+    @abc.abstractmethod
+    def message_attributes(self, queue_message) -> dict:
+        """
+        Decodes the consumer specific message payload.
+        """
+
     @contextmanager
-    def _maybe_instrument(self, **kwargs) -> Iterator:
+    def _maybe_instrument(self, attributes) -> Iterator:
         try:
             import hedwig.instrumentation
 
-            with hedwig.instrumentation.on_receive(**kwargs) as span:
+            with hedwig.instrumentation.on_receive(attributes) as span:
                 yield span
         except ImportError:
             yield None
@@ -137,7 +154,8 @@ class HedwigConsumerBaseBackend:
                 num_messages=num_messages, visibility_timeout=visibility_timeout, shutdown_event=shutdown_event
             )
             for queue_message in queue_messages:
-                with self._maybe_instrument(**self.pre_process_hook_kwargs(queue_message)):
+                self._last_message_received_at = datetime.utcnow()
+                with self._maybe_instrument(self.message_attributes(queue_message)):
                     try:
                         settings.HEDWIG_PRE_PROCESS_HOOK(**self.pre_process_hook_kwargs(queue_message))
                     except Exception:
@@ -153,8 +171,7 @@ class HedwigConsumerBaseBackend:
 
                     try:
                         self.process_message(queue_message)
-                        if self._error_count:  # type: ignore
-                            self._error_count = 0
+                        self._error_count = 0
                     except IgnoreException:
                         log(__name__, logging.INFO, 'Ignoring task', extra={'queue_message': queue_message})
                     except LoggingException as e:
@@ -172,6 +189,8 @@ class HedwigConsumerBaseBackend:
                         self.nack_message(queue_message)
                         self._error_count += 1
                         continue
+                    finally:
+                        self._call_heartbeat_hook()
 
                     try:
                         settings.HEDWIG_POST_PROCESS_HOOK(**self.post_process_hook_kwargs(queue_message))
@@ -197,12 +216,13 @@ class HedwigConsumerBaseBackend:
                             exc_info=True,
                         )
 
+    @abc.abstractmethod
     def extend_visibility_timeout(self, visibility_timeout_s: int, metadata) -> None:
         """
         Extends visibility timeout of a message on a given priority queue for long running tasks.
         """
-        raise NotImplementedError
 
+    @abc.abstractmethod
     def requeue_dead_letter(self, num_messages: int = 10, visibility_timeout: Optional[int] = None) -> None:
         """
         Re-queues everything in the Hedwig DLQ back into the Hedwig queue.
@@ -211,8 +231,8 @@ class HedwigConsumerBaseBackend:
         :param visibility_timeout: The number of seconds the message should remain invisible to other queue readers.
         Defaults to None, which is queue default
         """
-        raise NotImplementedError
 
+    @abc.abstractmethod
     def pull_messages(
         self,
         num_messages: int = 10,
@@ -226,20 +246,29 @@ class HedwigConsumerBaseBackend:
         :param visibility_timeout:
         :return: a tuple of list of messages and the queue they were pulled from
         """
-        raise NotImplementedError
 
+    @abc.abstractmethod
     def process_message(self, queue_message) -> None:
-        raise NotImplementedError
+        """
+        Processes the consumer specific message.
+        """
 
     def process_messages(self, lambda_event) -> None:
         # for lambda backend
         raise NotImplementedError
 
+    @abc.abstractmethod
     def ack_message(self, queue_message) -> None:
-        raise NotImplementedError
+        """
+        Acknowledges the message. This method is called when message is successfully processed.
+        """
 
+    @abc.abstractmethod
     def nack_message(self, queue_message) -> None:
-        raise NotImplementedError
+        """
+        Decline to acknowledge the given message. This method is called when message
+        when exception is raised during message processing.
+        """
 
     @staticmethod
     def _build_message(message_payload: Union[str, bytes], attributes: dict, provider_metadata: Any) -> Message:
@@ -252,6 +281,23 @@ class HedwigConsumerBaseBackend:
             _log_invalid_message(message_payload)
             raise
 
+    def _perform_error_counter_inactivity_reset(self):
+        if self._heartbeat_inactivity_reset_timedelta and self.error_count:
+            now = datetime.utcnow()
+            if self._last_message_received_at + self._heartbeat_inactivity_reset_timedelta < now:
+                self._error_count = 0
+                log(__name__, logging.INFO, 'Error counter was reset due to heartbeat inactivity settings')
+
+    def _call_heartbeat_hook(self, force: bool = False):
+        now = datetime.utcnow()
+        if force or self._heartbeat_called_at + self._heartbeat_interval_timedelta < now:
+            try:
+                settings.HEDWIG_HEARTBEAT_HOOK(**self.heartbeat_hook_kwargs())
+            except Exception:
+                log(__name__, logging.ERROR, 'Exception in heartbeat hook', exc_info=True)
+            finally:
+                self._heartbeat_called_at = now
+
     @property
     def error_count(self) -> int:
         """
