@@ -5,15 +5,15 @@ from unittest import mock
 import pytest
 
 import hedwig.conf
-from hedwig.backends.base import HedwigPublisherBaseBackend
 from hedwig.backends.import_utils import import_module_attr
 from hedwig.testing.config import unconfigure
+from tests import MockHedwigPublisherBackend
 
 from tests.models import MessageType
 
 try:
     # may not be available
-    from moto import mock_sqs, mock_sns
+    from moto import mock_aws
 except ImportError:
     pass
 
@@ -95,7 +95,8 @@ def message_with_trace(message_factory):
 @contextmanager
 def _mock_boto3():
     settings.AWS_REGION = 'us-west-1'
-    with mock_sqs(), mock_sns(), mock.patch("hedwig.backends.aws.boto3", autospec=True) as boto3_mock:
+
+    with mock_aws(), mock.patch("hedwig.backends.aws.boto3", autospec=True) as boto3_mock:
         yield boto3_mock
 
 
@@ -152,8 +153,8 @@ def publisher_backend(request, mock_boto3):
 
 @pytest.fixture()
 def mock_publisher_backend():
-    with mock.patch.object(HedwigPublisherBaseBackend, '_publish'):
-        yield HedwigPublisherBaseBackend()
+    with mock.patch.object(MockHedwigPublisherBackend, '_publish'):
+        yield MockHedwigPublisherBackend()
 
 
 @pytest.fixture(params=[True, False], ids=["message-attrs", "no-message-attrs"])
