@@ -5,32 +5,28 @@ from unittest import mock
 
 import pytest
 
-from hedwig.backends.base import HedwigConsumerBaseBackend, HedwigPublisherBaseBackend
 from hedwig.backends.utils import get_consumer_backend, get_publisher_backend
 from hedwig.conf import settings
-from hedwig.models import ValidationError
 from hedwig.exceptions import LoggingException, RetryException, IgnoreException
+from hedwig.models import ValidationError
+from tests import MockHedwigConsumerBackend, MockHedwigPublisherBackend
 from tests.utils.mock import mock_return_once
 
 
-class MockBackend(HedwigConsumerBaseBackend, HedwigPublisherBaseBackend):
-    pass
-
-
 class TestBackends:
     def test_success_get_consumer_backend(self, settings):
-        settings.HEDWIG_CONSUMER_BACKEND = "tests.test_backends.test_base.MockBackend"
+        settings.HEDWIG_CONSUMER_BACKEND = "tests.MockHedwigConsumerBackend"
 
         consumer_backend = get_consumer_backend()
 
-        assert isinstance(consumer_backend, MockBackend)
+        assert isinstance(consumer_backend, MockHedwigConsumerBackend)
 
     def test_success_get_publisher_backend(self, settings):
-        settings.HEDWIG_PUBLISHER_BACKEND = "tests.test_backends.test_base.MockBackend"
+        settings.HEDWIG_PUBLISHER_BACKEND = "tests.MockHedwigPublisherBackend"
 
         publisher_backend = get_publisher_backend()
 
-        assert isinstance(publisher_backend, MockBackend)
+        assert isinstance(publisher_backend, MockHedwigPublisherBackend)
 
     @pytest.mark.parametrize("get_backend_fn", [get_publisher_backend, get_consumer_backend])
     def test_failure(self, get_backend_fn, settings):
@@ -71,6 +67,18 @@ class TestMessageHandler:
 
 pre_process_hook = mock.MagicMock()
 post_process_hook = mock.MagicMock()
+heartbeat_hook = mock.MagicMock()
+
+
+@pytest.fixture(name='prepost_process_hooks')
+def _prepost_process_hooks(settings):
+    settings.HEDWIG_HEARTBEAT_HOOK = 'tests.test_backends.test_base.heartbeat_hook'
+    settings.HEDWIG_PRE_PROCESS_HOOK = 'tests.test_backends.test_base.pre_process_hook'
+    settings.HEDWIG_POST_PROCESS_HOOK = 'tests.test_backends.test_base.post_process_hook'
+    yield
+    pre_process_hook.reset_mock(side_effect=True)
+    post_process_hook.reset_mock(side_effect=True)
+    heartbeat_hook.reset_mock(side_effect=True)
 
 
 class TestFetchAndProcessMessages:
@@ -124,10 +132,8 @@ class TestFetchAndProcessMessages:
 
         consumer_backend.ack_message.assert_called_once_with(queue_message)
 
-    def test_pre_process_hook(self, consumer_backend, settings):
+    def test_pre_process_hook(self, consumer_backend, prepost_process_hooks):
         shutdown_event = threading.Event()
-        pre_process_hook.reset_mock()
-        settings.HEDWIG_PRE_PROCESS_HOOK = 'tests.test_backends.test_base.pre_process_hook'
         consumer_backend.process_message = mock.MagicMock()
         consumer_backend.pull_messages = mock.MagicMock()
         mock_return_once(consumer_backend.pull_messages, [mock.MagicMock(), mock.MagicMock()], [], shutdown_event)
@@ -141,12 +147,10 @@ class TestFetchAndProcessMessages:
             ]
         )
 
-    def test_pre_process_hook_exception(self, consumer_backend, settings):
+    def test_pre_process_hook_exception(self, consumer_backend, prepost_process_hooks):
         shutdown_event = threading.Event()
-        pre_process_hook.reset_mock()
         pre_process_hook.side_effect = RuntimeError('fail')
         queue_message = mock.MagicMock()
-        settings.HEDWIG_PRE_PROCESS_HOOK = 'tests.test_backends.test_base.pre_process_hook'
         consumer_backend.process_message = mock.MagicMock()
         consumer_backend.pull_messages = mock.MagicMock()
         mock_return_once(consumer_backend.pull_messages, [queue_message], [], shutdown_event)
@@ -165,10 +169,8 @@ class TestFetchAndProcessMessages:
         pre_process_hook.assert_called_once_with(**consumer_backend.pre_process_hook_kwargs(queue_message))
         queue_message.delete.assert_not_called()
 
-    def test_post_process_hook(self, consumer_backend, settings):
+    def test_post_process_hook(self, consumer_backend, prepost_process_hooks):
         shutdown_event = threading.Event()
-        post_process_hook.reset_mock()
-        settings.HEDWIG_POST_PROCESS_HOOK = 'tests.test_backends.test_base.post_process_hook'
         consumer_backend.process_message = mock.MagicMock()
         consumer_backend.pull_messages = mock.MagicMock()
         mock_return_once(consumer_backend.pull_messages, [mock.MagicMock(), mock.MagicMock()], [], shutdown_event)
@@ -182,14 +184,12 @@ class TestFetchAndProcessMessages:
             ]
         )
 
-    def test_post_process_hook_exception(self, consumer_backend, settings):
+    def test_post_process_hook_exception(self, consumer_backend, prepost_process_hooks):
         shutdown_event = threading.Event()
-        settings.HEDWIG_POST_PROCESS_HOOK = 'tests.test_backends.test_base.post_process_hook'
         consumer_backend.process_message = mock.MagicMock()
         consumer_backend.pull_messages = mock.MagicMock()
         queue_message = mock.MagicMock()
         mock_return_once(consumer_backend.pull_messages, [queue_message], [], shutdown_event)
-        post_process_hook.reset_mock()
         post_process_hook.side_effect = RuntimeError('fail')
 
         with mock.patch('hedwig.backends.base.log') as logging_mock:
@@ -261,7 +261,7 @@ class TestFetchAndProcessMessages:
             consumer_backend.fetch_and_process_messages(shutdown_event=shutdown_event)
 
             logging_mock.assert_called_with('hedwig.backends.base', logging.ERROR, mock.ANY, exc_info=True)
-            logging_mock.call_count == 2
+            assert logging_mock.call_count == 2
 
         assert consumer_backend.error_count == 2
 
@@ -281,6 +281,24 @@ class TestFetchAndProcessMessages:
         # error count is reset to 0
         assert consumer_backend.error_count == 0
 
+    def test_heartbeat_hook_called_once_when_multiple_messages_are_processed(
+        self, consumer_backend, prepost_process_hooks
+    ):
+        shutdown_event = threading.Event()
+        queue_message = mock.MagicMock()
+        consumer_backend.pull_messages = mock.MagicMock()
+        mock_return_once(
+            consumer_backend.pull_messages, [queue_message, queue_message, queue_message], [], shutdown_event
+        )
+
+        # process message normally
+        consumer_backend.process_message = mock.MagicMock()
+        consumer_backend.fetch_and_process_messages(shutdown_event=shutdown_event)
+
+        assert pre_process_hook.call_count == 3
+        assert post_process_hook.call_count == 3
+        heartbeat_hook.assert_called_once_with(error_count=0)
+
 
 default_headers = mock.MagicMock(return_value={'mickey': 'mouse'})
 
