@@ -1,5 +1,5 @@
 import threading
-from datetime import datetime, timezone
+from datetime import datetime, timedelta, timezone
 from unittest import mock
 
 import freezegun
@@ -111,6 +111,7 @@ class TestPubSubPublisher:
 
 pre_process_hook = mock.MagicMock()
 post_process_hook = mock.MagicMock()
+heartbeat_hook = mock.MagicMock()
 
 
 @pytest.fixture(name='subscription_paths')
@@ -126,15 +127,17 @@ def _gcp_consumer(mock_pubsub_v1, gcp_settings, subscription_paths):
 
 @pytest.fixture(name='prepost_process_hooks')
 def _prepost_process_hooks(gcp_settings):
+    gcp_settings.HEDWIG_HEARTBEAT_HOOK = 'tests.test_backends.test_gcp.heartbeat_hook'
     gcp_settings.HEDWIG_PRE_PROCESS_HOOK = 'tests.test_backends.test_gcp.pre_process_hook'
     gcp_settings.HEDWIG_POST_PROCESS_HOOK = 'tests.test_backends.test_gcp.post_process_hook'
     yield
-    pre_process_hook.reset_mock()
-    post_process_hook.reset_mock()
+    pre_process_hook.reset_mock(side_effect=True)
+    post_process_hook.reset_mock(side_effect=True)
+    heartbeat_hook.reset_mock(side_effect=True)
 
 
 class TestGCPConsumer:
-    def test_pull_messages(self, mock_pubsub_v1, gcp_consumer, subscription_paths):
+    def test_pull_messages(self, mock_pubsub_v1, gcp_consumer, subscription_paths, prepost_process_hooks):
         shutdown_event = threading.Event()
         num_messages = 1
         visibility_timeout = 10
@@ -192,8 +195,50 @@ class TestGCPConsumer:
                 for x in range(4)
             ]
         )
+        heartbeat_hook.assert_called_once_with(error_count=0)
 
-    def test_success_extend_visibility_timeout(self, gcp_consumer):
+    @pytest.mark.parametrize(
+        "inactivity_s,last_message_received_delta_s,expected_error_count",
+        [(None, 0, 1), (10, 1, 1), (1, 2, 0)],
+        ids=["reset-disabled", "reset-enabled-inactivity-period-not-reached", "reset-enabled"],
+    )
+    def test_pull_messages_error_count_inactivity_reset(
+        self,
+        mock_pubsub_v1,
+        gcp_settings,
+        subscription_paths,
+        prepost_process_hooks,
+        inactivity_s,
+        last_message_received_delta_s,
+        expected_error_count,
+    ):
+        class _Event(threading.Event):
+            def __init__(self, max_calls):
+                super().__init__()
+                self.max_calls = max_calls
+                self.counter = 0
+
+            def is_set(self):
+                if self.counter == self.max_calls:
+                    self.set()
+                self.counter += 1
+                return super().is_set()
+
+        shutdown_event = _Event(max_calls=1)
+        num_messages = 1
+        visibility_timeout = 10
+        mock_pubsub_v1.SubscriberClient.subscription_path.side_effect = subscription_paths
+        gcp_settings.HEDWIG_HEARTBEAT_INACTIVITY_RESET_S = inactivity_s
+        gcp_consumer = gcp.GooglePubSubConsumerBackend()
+        gcp_consumer._last_message_received_at = datetime.utcnow() - timedelta(seconds=last_message_received_delta_s)
+        gcp_consumer._error_count = 1
+
+        list(gcp_consumer.pull_messages(num_messages, visibility_timeout, shutdown_event=shutdown_event))
+
+        assert gcp_consumer._error_count == expected_error_count
+        heartbeat_hook.assert_called_once_with(error_count=expected_error_count)
+
+    def test_success_extend_visibility_timeout(self, gcp_consumer, prepost_process_hooks):
         visibility_timeout_s = 10
         ack_id = "dummy_ack_id"
         subscription_path = "subscriptions/foobar"
@@ -207,9 +252,10 @@ class TestGCPConsumer:
         gcp_consumer.subscriber.modify_ack_deadline.assert_called_once_with(
             subscription=subscription_path, ack_ids=[ack_id], ack_deadline_seconds=visibility_timeout_s
         )
+        heartbeat_hook.assert_called_once_with(error_count=0)
 
     @pytest.mark.parametrize("visibility_timeout", [-1, 601])
-    def test_failure_extend_visibility_timeout(self, visibility_timeout, gcp_consumer):
+    def test_failure_extend_visibility_timeout(self, visibility_timeout, gcp_consumer, prepost_process_hooks):
         subscription_path = "subscriptions/foobar"
         publish_time = datetime.now(timezone.utc)
         delivery_attempt = 1
@@ -221,6 +267,7 @@ class TestGCPConsumer:
 
         gcp_consumer.subscriber.subscription_path.assert_not_called()
         gcp_consumer.subscriber.modify_ack_deadline.assert_not_called()
+        heartbeat_hook.assert_not_called()
 
     def test_success_requeue_dead_letter(self, mock_pubsub_v1, message, use_transport_message_attrs):
         gcp_consumer = gcp.GooglePubSubConsumerBackend(dlq=True)
@@ -323,3 +370,4 @@ class TestGCPConsumer:
         queue_message.ack.assert_called_once_with()
         pre_process_hook.assert_called_once_with(google_pubsub_message=queue_message)
         post_process_hook.assert_called_once_with(google_pubsub_message=queue_message)
+        heartbeat_hook.assert_called_once_with(error_count=0)
