@@ -1,14 +1,14 @@
 import re
 
-from hedwig.validator import MessageValidator
+from hedwig.validators.jsonschema import JSONSchemaValidator
 
 
-class CustomValidator(MessageValidator):
+class CustomValidator(JSONSchemaValidator):
     # simplistic check: 17 alphanumeric characters except i, o, q
     _vin_re = re.compile("^[a-hj-npr-z0-9]{17}$")
 
     @staticmethod
-    @MessageValidator.checker.checks('vin')
+    @JSONSchemaValidator.checker.checks('vin')
     def check_vin(instance) -> bool:
         if not isinstance(instance, str):
             return True
